@@ -323,26 +323,30 @@ def get_params(args):
         output_dir_subject = f"{args.output_dir}/{subject_id}"
         params = [(output_dir_subject, args.input_path)]
     if None is args.rois:
-        roi_bins = list(range(112))
+        args.rois = list(range(112))
     else:
-        roi_bins = get_deeparcel_rois(args.rois)
-    return params, roi_bins, args.including_gpus, args.excluding_gpus, args.purge_output is not None and args.purge_output
+        args.rois = get_deeparcel_rois(args.rois)
+    args.purge_output = args.purge_output is not None and args.purge_output
+    return params
 
 def check_weight_files():
     parent_dir = os.path.dirname(os.path.abspath(__file__))
-    if os.path.exists(f"{parent_dir}/weights/weight-roi_0.h5"):
+    an_weight_file = f"{parent_dir}/weights/weight-roi_0.h5"
+    if os.path.exists(an_weight_file) and os.path.getsize(an_weight_file) > 0:
         return
-    print("[check_weight_files] Installing weights")
     output_path = f"{parent_dir}/weights.tar.gz"
-    input_url = "https://github.com/abysslover/deepparcellation/releases/download/v1.0.0/weights.tar.gz"
-    import urllib.request
-    import tarfile
-    with urllib.request.urlopen(input_url) as response, open(output_path, "wb") as out_file:
-        data = response.read()
-        out_file.write(data)
-    
-    with tarfile.open(output_path, "r:gz") as tar:
-        tar.extractall()
+    print(f"[check_weight_files] Install weights: {output_path}")
+    if not os.path.exists(output_path):
+        input_url = "https://github.com/abysslover/deepparcellation/releases/download/v1.0.0/weights.tar.gz"
+        import urllib.request
+        with urllib.request.urlopen(input_url) as response, open(output_path, "wb") as out_file:
+            data = response.read()
+            out_file.write(data)
+
+    print(f"[check_weight_files] Uncompress weights: {output_path}")
+    import tarfile    
+    with tarfile.open(output_path, "r") as tar:
+        tar.extractall(path=parent_dir)
     os.remove(output_path)
 
 def main():
@@ -358,11 +362,11 @@ def main():
     parser.add_argument("-o", "--output_dir", required=False,
                         help="Output directory")
     parser.add_argument("-r", "--rois", required=False,
-                        help="ROIs to be parcellated (refers to the freesurfer ROI)")
+                        help="comma-separated ROIs to be parcellated (refers to the freesurfer ROI)")
     parser.add_argument("-g", "--including_gpus", required=False,
-                        help="numeric GPU IDs that will be used")
+                        help="comma-separated numeric GPU IDs that will be used")
     parser.add_argument("-G", "--excluding_gpus", required=False,
-                        help="numeric GPU IDs that will not be used")
+                        help="comma-separated numeric GPU IDs that will not be used")
     parser.add_argument("-j", "--n_cores", required=False,
                         default=n_cores,
                         help="# CPU cores when running predictions on CPUs")
@@ -372,15 +376,15 @@ def main():
     
     args = parser.parse_args()
     
-    params, roi_bins, including_gpus, excluding_gpus, is_purge = get_params(args)
-    gpus, n_chunks = get_available_GPUs(including_gpus=including_gpus, excluding_gpus=excluding_gpus)
+    params = get_params(args)
+    gpus, n_chunks = get_available_GPUs(including_gpus=args.including_gpus, excluding_gpus=args.excluding_gpus)
     mode = "cpu" if 0 == len(gpus) else "gpu"
     if "gpu" == mode:
         print(f"[main] # samples: {len(params)}, mode: {mode}, # chunks: {n_chunks}")
-        predict_in_batch_mode(params, gpus, n_chunks, roi_bins=roi_bins, is_purge=is_purge)
+        predict_in_batch_mode(params, gpus, n_chunks, roi_bins=args.rois, is_purge=args.purge_output)
     else:
         print(f"[main] # samples: {len(params)}, mode: {mode}")
-        predict_in_batch_mode_cpu(params, n_cores, roi_bins=roi_bins, is_purge=is_purge)
+        predict_in_batch_mode_cpu(params, args.n_cores, roi_bins=args.rois, is_purge=args.purge_output)
 
 
 if __name__ == '__main__':
